# django-duke-core
A project to help you build your django project faster by using a collection of predefined apps.

## Approach
This project is a collection of django apps that can be used to build a django project faster.
The apps are also designed to be as independent as possible so that you can use only the apps you need.

### Entrypoints
One of the main mechanism used in this project is the `entrypoint` approach.
Entrypoints are a way to extend the functionality of a project without having to modify the project itself.

## Name of the project
Edward Kennedy "Duke" Ellington was an American composer, pianist, and leader of a jazz orchestra.
He was one of the most important musicians in the history of recorded music, and is called one of the greatest figures in jazz music.
He was playing with Django Reinhardt in 1946.
Django is the name of the framework and Duke is the name of the project.
